starcluster.image

Package starcluster :: Module image |
[hide private]
[frames] | no frames]

# Module image

source code

Classes | [hide private]
| ImageCreator Base class for S3/EBS Image Creators.
| S3ImageCreator Class for creating a new instance-store AMI from a running instance
| EBSImageCreator Creates a new EBS image from a running instance
| EC2ImageCreator Class for creating a new instance-store AMI from a running instance

Variables | [hide private]
| __package__ = ``'``starcluster``'``